<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet (lowercase and without spaces)
	$themename = get_option( 'stylesheet' );
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	
	$optionsframework_settings = get_option('optionsframework');
	$optionsframework_settings['id'] = $themename;
	update_option('optionsframework', $optionsframework_settings);
	
	// echo $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */

function optionsframework_options() {
	
	// Test data
	$test_array = array("1" => "Tutorials","2" => "Записи");
	
	// Multicheck Array
	$multicheck_array = array("one" => "French Toast", "two" => "Pancake", "three" => "Omelette", "four" => "Crepe", "five" => "Waffle");
	
	// Multicheck Defaults
	$multicheck_defaults = array("one" => "1","five" => "1");
	
	// Background Defaults
	
	$background_defaults = array('color' => '', 'image' => '', 'repeat' => 'repeat','position' => 'top center','attachment'=>'scroll');
	
	
	// Pull all the categories into an array
	$options_categories = array();  
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_bloginfo('stylesheet_directory') . '/images/';
		
	$options = array();
	
	
	$options[] = array( "name" => "General",
						"type" => "heading");	


	
	$options[] = array( "name" => "Записи в блоге на главной странице",
						"desc" => "Введите число записей, которые будут показаны на главной странице карусели",
						"id" => "w2f_blog_number",
						"std" => "",
						"type" => "text");	
						


	$options[] = array( "name" => "Slider",
						"type" => "heading");	
						
						
	$options[] = array( "name" => "Категории слайда",
						"desc" => "Выберите категорию для изображения слайдера",
						"id" => "w2f_slide_categories",
						"type" => "select",
						"options" => $options_categories);						
						
	$options[] = array( "name" => "Число слайдов",
						"desc" => "Введите число слайдов",
						"id" => "w2f_slide_number",
						"std" => "",
						"type" => "text");							
						

						
	$options[] = array( "name" => "Настройки баннера",
						"type" => "heading");		
						
						
						
	$options[] = array( "name" => "Баннер 1 изображения",
						"desc" => "Введите баннер изображения 125x125 URL.",
						"id" => "w2f_banner1",
						"std" => "http://web2feel.com/images/webhostinghub.png",
						"type" => "text");		
						
	$options[] = array( "name" => "Баннер 1 Изображения альт тег",
						"desc" => "Введите баннер 1 Изображение альт тег.",
						"id" => "w2f_alt1",
						"std" => "Дешевые надежный хостинг от WebHostingHub.com",
						"type" => "text");		
						
	$options[] = array( "name" => "Баннер 1 Url",
						"desc" => "Введите баннер 1 Url.",
						"id" => "w2f_url1",
						"std" => "http://www.webhostinghub.com/",
						"type" => "text");						
						
	$options[] = array( "name" => "Баннер 1 ссылки",
						"desc" => "Введите баннер 1 ссылки.",
						"id" => "w2f_lab1",
						"std" => "Web Hosting Hub - Дешевые надежный хостинг.",
						"type" => "text");						
						


	$options[] = array( "name" => "Баннер 2 изображения",
						"desc" => "Введите баннер изображения 125 x 125 url.",
						"id" => "w2f_banner2",
						"std" => "http://web2feel.com/images/pcnames.png",
						"type" => "text");		

	$options[] = array( "name" => "Баннер 2 изображения альт тег",
						"desc" => "Введите 2 баннер изображения альт тег.",
						"id" => "w2f_alt2",
						"std" => "Поиск домена имя и проверка доступности от PCNames.com",
						"type" => "text");		

	$options[] = array( "name" => "Баннер 2 Url",
						"desc" => "Введите 2 баннер url .",
						"id" => "w2f_url2",
						"std" => "http://www.pcnames.com/",
						"type" => "text");						

	$options[] = array( "name" => "Баннер 2 название ссылки",
						"desc" => "Введите баннер 2-название сслыки.",
						"id" => "w2f_lab2",
						"std" => "Имя PC - Поиск домена  и проверка доступности.",
						"type" => "text");
										
										
																
	$options[] = array( "name" => "Баннер 3 изображения",
						"desc" => "Введите баннер изображения 125 x 125 url.",
						"id" => "w2f_banner3",
						"std" => "http://web2feel.com/images/designcontest.png",
						"type" => "text");		

	$options[] = array( "name" => "Баннер 3 изображение альт тег",
						"desc" => "Введите баннер 3 изображения альт тег.",
						"id" => "w2f_alt3",
						"std" => "Веб-сайт и дизайн логотипа  на DesignContest.com.",
						"type" => "text");		

	$options[] = array( "name" => "Баннер 3 Url",
						"desc" => "Введите баннер название ссылки 1 url.",
						"id" => "w2f_url3",
						"std" => "http://www.designcontest.com/",
						"type" => "text");						

	$options[] = array( "name" => "Баннер 3 ссылка на изображение",
						"desc" => "Введите баннер-3 ссылка на изображение.",
						"id" => "w2f_lab3",
						"std" => "Design Contest - логотип и дизайн сайта.",
						"type" => "text");
								
								
														
																				
	$options[] = array( "name" => "Баннер изображения 4 ",
						"desc" => "Введите баннер изображения 125 x 125 url.",
						"id" => "w2f_banner4",
						"std" => "http://web2feel.com/images/webhostingrating.png",
						"type" => "text");		

	$options[] = array( "name" => "Баннер изображения 4 альт тег",
						"desc" => "Введите баннер альт тег.",
						"id" => "w2f_alt4",
						"std" => "Обзоры лучших дешевые веб-хостинг-провайдеров в WebHostingRating.com",
						"type" => "text");		

	$options[] = array( "name" => "Баннер 4 Url",
						"desc" => "Введите баннер изображения 4 url .",
						"id" => "w2f_url4",
						"std" => "http://webhostingrating.com",
						"type" => "text");						

	$options[] = array( "name" => "Баннер название ссылки 4 ",
						"desc" => "Введите название ссылки 4.",
						"id" => "w2f_lab4",
						"std" => "Web Hosting Rating - Отзывы клиентов из лучших веб-хосты",
						"type" => "text");						
						
						
						
						
								// 					
								// 					
								// 					
								// 					
								// 					
								// 	
								// $options[] = array( "name" => "Basic Settings",
								// 					"type" => "heading");
								// 						
								// $options[] = array( "name" => "Input Text Mini",
								// 					"desc" => "A mini text input field.",
								// 					"id" => "example_text_mini",
								// 					"std" => "Default",
								// 					"class" => "mini",
								// 					"type" => "text");
								// 							
								// $options[] = array( "name" => "Input Text",
								// 					"desc" => "A text input field.",
								// 					"id" => "example_text",
								// 					"std" => "Default Value",
								// 					"type" => "text");
								// 						
								// $options[] = array( "name" => "Textarea",
								// 					"desc" => "Textarea description.",
								// 					"id" => "example_textarea",
								// 					"std" => "Default Text",
								// 					"type" => "textarea"); 
								// 					
								// $options[] = array( "name" => "Input Select Small",
								// 					"desc" => "Small Select Box.",
								// 					"id" => "example_select",
								// 					"std" => "three",
								// 					"type" => "select",
								// 					"class" => "mini", //mini, tiny, small
								// 					"options" => $test_array);			 
								// 					
								// $options[] = array( "name" => "Input Select Wide",
								// 					"desc" => "A wider select box.",
								// 					"id" => "example_select_wide",
								// 					"std" => "two",
								// 					"type" => "select",
								// 					"options" => $test_array);
								// 					
								// $options[] = array( "name" => "Select a Category",
								// 					"desc" => "Passed an array of categories with cat_ID and cat_name",
								// 					"id" => "example_select_categories",
								// 					"type" => "select",
								// 					"options" => $options_categories);
								// 					
								// $options[] = array( "name" => "Select a Page",
								// 					"desc" => "Passed an pages with ID and post_title",
								// 					"id" => "example_select_pages",
								// 					"type" => "select",
								// 					"options" => $options_pages);
								// 					
								// $options[] = array( "name" => "Input Radio (one)",
								// 					"desc" => "Radio select with default options 'one'.",
								// 					"id" => "example_radio",
								// 					"std" => "one",
								// 					"type" => "radio",
								// 					"options" => $test_array);
								// 						
								// $options[] = array( "name" => "Example Info",
								// 					"desc" => "This is just some example information you can put in the panel.",
								// 					"type" => "info");
								// 										
								// $options[] = array( "name" => "Input Checkbox",
								// 					"desc" => "Example checkbox, defaults to true.",
								// 					"id" => "example_checkbox",
								// 					"std" => "1",
								// 					"type" => "checkbox");
								// 					
								// $options[] = array( "name" => "Advanced Settings",
								// 					"type" => "heading");
								// 					
								// $options[] = array( "name" => "Check to Show a Hidden Text Input",
								// 					"desc" => "Click here and see what happens.",
								// 					"id" => "example_showhidden",
								// 					"type" => "checkbox");
								// 
								// $options[] = array( "name" => "Hidden Text Input",
								// 					"desc" => "This option is hidden unless activated by a checkbox click.",
								// 					"id" => "example_text_hidden",
								// 					"std" => "Hello",
								// 					"class" => "hidden",
								// 					"type" => "text");
								// 					
								// $options[] = array( "name" => "Uploader Test",
								// 					"desc" => "This creates a full size uploader that previews the image.",
								// 					"id" => "example_uploader",
								// 					"type" => "upload");
								// 					
								// 
								// 					
								// $options[] = array( "name" =>  "Example Background",
								// 					"desc" => "Change the background CSS.",
								// 					"id" => "example_background",
								// 					"std" => $background_defaults, 
								// 					"type" => "background");
								// 							
								// $options[] = array( "name" => "Multicheck",
								// 					"desc" => "Multicheck description.",
								// 					"id" => "example_multicheck",
								// 					"std" => $multicheck_defaults, // These items get checked by default
								// 					"type" => "multicheck",
								// 					"options" => $multicheck_array);
								// 						
								// $options[] = array( "name" => "Colorpicker",
								// 					"desc" => "No color selected by default.",
								// 					"id" => "example_colorpicker",
								// 					"std" => "",
								// 					"type" => "color");
								// 					
								// $options[] = array( "name" => "Typography",
								// 					"desc" => "Example typography.",
								// 					"id" => "example_typography",
								// 					"std" => array('size' => '12px','face' => 'verdana','style' => 'bold italic','color' => '#123456'),
								// 					"type" => "typography");			
	return $options;
}